![PTTLibrary: A PTT Library in Python](https://i.imgur.com/B1kIMgR.png)
# PTT Library
[![Package Version](https://img.shields.io/pypi/v/PTTLibrary.svg)](https://pypi.python.org/pypi/PTTLibrary)
[![Build Status](https://travis-ci.org/Truth0906/PTTLibrary.svg?branch=master)](https://travis-ci.org/Truth0906/PTTLibrary)
[![Codacy Badge](https://api.codacy.com/project/badge/grade/8f2eee1a277d499f95dfd5ee46094fdf)](https://www.codacy.com/app/Truth0906/PTTLibrary)
[![Requirements Status](https://requires.io/github/Truth0906/PTTLibrary/requirements.svg?branch=master)](https://requires.io/github/Truth0906/PTTLibrary/requirements/?branch=master)
![license](https://img.shields.io/github/license/mashape/apistatus.svg)
[![Join the chat at https://gitter.im/PTTLibrary/Lobby](https://badges.gitter.im/PTTLibrary/Lobby.svg)](https://gitter.im/PTTLibrary/Lobby?utm_source=badge&utm_medium=badge&utm_content=badge)

#### PTT Library 是一個由 Python 所開發，用來操作 PTT 的函式庫
#### 無論推文、發文、爬蟲、寄信、發 P 幣、丟水球還是狂查人家 ID，都可以滿足你的需求
#### 使用最新的 WebSocket 連線模式
#### 支援多國語系，繁體中文與英文
#### 歡迎發起 pull request，提交你開發的 API
#### 測試平台: Windows 10, Ubuntu 18.04, MacOS 10.14
#### 原始碼
#### github: https://github.com/Truth0906/PTTLibrary
#### Pypi: https://pypi.org/project/PTTLibrary/

### 介紹影片 (感謝 NaeNPIANO 介紹)
[![](http://img.youtube.com/vi/ng48ITuePlg/0.jpg)](http://www.youtube.com/watch?v=ng48ITuePlg "")

## 版本
#### [![Package Version](https://img.shields.io/pypi/v/PTTLibrary.svg)](https://pypi.python.org/pypi/PTTLibrary)

## 取得
#### 安裝
#### Windows 使用 pip, Linux and Mac 使用 pip3
```bash
pip install PTTLibrary
```

## 詳細說明
#### [PTT Library 手冊](https://hackmd.io/@CodingMan/PTTLibraryManual) 有 API 的詳細範例與參數說明

## 回報問題
#### 1. 請閱讀 [PTT Library 手冊](https://hackmd.io/@CodingMan/PTTLibraryManual) 確認使用方法無誤並確認你所使用的版本為 [![Package Version](https://img.shields.io/pypi/v/PTTLibrary.svg)](https://pypi.python.org/pypi/PTTLibrary) 如果是舊版本請更新後複測
#### 2. 如果問題還是存在，請參考手冊中的 [初始設定](https://hackmd.io/JAiqhriyQVe_TJleNwLWTQ#%E5%88%9D%E5%A7%8B%E8%A8%AD%E5%AE%9A) 將 Log level 調整成 TRACE 後截圖並附上 PTT Library 的相關程式碼
#### 3. 開個 [issue](https://github.com/Truth0906/PTTLibrary/issues/new) 追蹤問題也可以直接在 gitter 上問我 [![Join the chat at https://gitter.im/PTTLibrary/Lobby](https://badges.gitter.im/PTTLibrary/Lobby.svg)](https://gitter.im/PTTLibrary/Lobby?utm_source=badge&utm_medium=badge&utm_content=badge) ~~或聊天~~

## 需求
#### Python ≥ 3.6

## 相依函式庫
#### progressbar2
#### websockets
#### uao

## 贊助
#### 在這個 github 的小園地，用熱血的心為您打造在 PTT 翱翔的翅膀。
#### 希望您可以贊助這雙翅膀，讓我們一起飛得更遠，
####
#### Paypal
#### [贊助連結](http://paypal.me/CodingMan)
####
#### XMR
#### 448CUe2q4Ecf9tx6rwanrqM9kfCwqpNbhJ5jtrTf9FHqHNq7Lvv9uBoQ74SEaAu9FFceNBr6p3W1yhqPcxPPSSTv2ctufnQ

## 贊助清單

#### 尚無贊助
